Introduction to CubicWeb — CubicWeb 3.13.2

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »

# Introduction to CubicWeb

This first part of the book offers different reading path to discover the CubicWeb framework, provides a tutorial to get a quick overview of its features and lists its key concepts.

- 1. A little history...
- 2. The Core Concepts of CubicWeb
  - 2.1. Cubes
  - 2.2. Instances
  - 2.3. Data Repository
  - 2.4. Web Engine
  - 2.5. Schema (Data Model)
  - 2.6. Registries and application objects
  - 2.7. The RQL query language
  - 2.8. Views
  - 2.9. Hooks and operations

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »